%global python_package_src command_line_assistant
%global binary_name c
%global daemon_binary_name clad

Name:           command-line-assistant
Version:        0.1.0
Release:        1.20250106175740808292.pr96.37.ge005e9c%{?dist}
Summary:        A simple wrapper to interact with RAG

License:        Apache-2.0
URL:            https://github.com/rhel-lightspeed/command-line-assistant
Source0:        command-line-assistant-0.1.0.tar.gz
# noarch because there is no extension module for this package.
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildRequires:  python3-pip
BuildRequires:  systemd-units

Requires:       python3-dasbus
Requires:       python3-requests
Requires:       systemd

# Not needed after RHEL 10 as it is native in Python 3.11+
%if 0%{?rhel} && 0%{?rhel} < 10
BuildRequires:  python3-tomli
Requires:       python3-tomli
%endif

%description
A simple wrapper to interact with RAG

%prep
%autosetup -n command-line-assistant-0.1.0

%build
%py3_build_wheel

%install
%py3_install_wheel %{python_package_src}-%{version}-py3-none-any.whl

# Create needed directories in buildroot
%{__install} -d %{buildroot}/%{_sbindir}
%{__install} -d %{buildroot}/%{_sysconfdir}/xdg/%{name}
%{__install} -d %{buildroot}/%{_sharedstatedir}/%{name}
%{__install} -d %{buildroot}/%{_mandir}/man1
%{__install} -d %{buildroot}/%{_mandir}/man8

# Move the daemon to /usr/sbin instead of /usr/bin
%{__install} -m 0755 %{buildroot}/%{_bindir}/%{daemon_binary_name} %{buildroot}/%{_sbindir}/%{daemon_binary_name}
%{__rm} %{buildroot}/%{_bindir}/%{daemon_binary_name}

# System units
%{__install} -D -m 0644 data/release/systemd/%{daemon_binary_name}.service %{buildroot}/%{_unitdir}/%{daemon_binary_name}.service

# d-bus policy config
%{__install} -D -m 0644 data/release/dbus/com.redhat.lightspeed.conf %{buildroot}/%{_sysconfdir}/dbus-1/system.d/com.redhat.lightspeed.conf
%{__install} -D -m 0644 data/release/dbus/com.redhat.lightspeed.query.service %{buildroot}/%{_datadir}/dbus-1/system-services/com.redhat.lightspeed.query.service
%{__install} -D -m 0644 data/release/dbus/com.redhat.lightspeed.history.service %{buildroot}/%{_datadir}/dbus-1/system-services/com.redhat.lightspeed.history.service

# Config file
%{__install} -D -m 0644 data/release/xdg/config.toml %{buildroot}/%{_sysconfdir}/xdg/%{name}/config.toml

# History file
%{__install} -D -m 0644 data/release/xdg/history.json %{buildroot}/%{_sharedstatedir}/%{name}/history.json

# Manpages
%{__install} -D -m 0644 data/release/man/%{binary_name}.1 %{buildroot}/%{_mandir}/man1/%{binary_name}.1
%{__install} -D -m 0644 data/release/man/%{daemon_binary_name}.8 %{buildroot}/%{_mandir}/man8/%{daemon_binary_name}.8

%post
%systemd_post %{daemon_binary_name}.service

%preun
%systemd_preun %{daemon_binary_name}.service

%postun
%systemd_postun_with_restart %{daemon_binary_name}.service

%doc
README.md

%license
LICENSE

%files
%{python3_sitelib}/%{python_package_src}/
%{python3_sitelib}/%{python_package_src}-%{version}.dist-info/

# Binaries
%{_bindir}/%{binary_name}
%{_sbindir}/%{daemon_binary_name}

# System units
%{_unitdir}/%{daemon_binary_name}.service

# d-bus policy config
%config %{_sysconfdir}/dbus-1/system.d/com.redhat.lightspeed.conf
%{_datadir}/dbus-1/system-services/com.redhat.lightspeed.query.service
%{_datadir}/dbus-1/system-services/com.redhat.lightspeed.history.service

# Config file
%config %{_sysconfdir}/xdg/%{name}/config.toml

# History file
%{_sharedstatedir}/%{name}/history.json

# Manpages
%{_mandir}/man1/%{binary_name}.1.gz
%{_mandir}/man8/%{daemon_binary_name}.8.gz

%changelog
* Mon Jan 06 2025 Packit <hello@packit.dev> - 0.1.0-1.20250106175740808292.pr96.37.ge005e9c
- Normalize the folder name to command-line-assistant (Rodolfo Olivieri)
- [RSPEED-388] Add exception handling for SSL certificates (#87) (Rodolfo Olivieri)
- Add audit logging capability to CLAD (#90) (Rodolfo Olivieri)
- [RSPEED-403] Prevent binary stdin (#92) (Rodolfo Olivieri)
- [RSPEED-334] Generate manpages for CLA and CLAD (#91) (Rodolfo Olivieri)
- Apply NO_COLOR to colored output (#88) (Rodolfo Olivieri)
- Small modifications to CONTRIBUTING.md (#86) (Rodolfo Olivieri)
- Remove colorama dependency and use only unicodes (#85) (Rodolfo Olivieri)
- Fix makefile systemd comment (#84) (Rodolfo Olivieri)
- Fix query read from stdin (#83) (Rodolfo Olivieri)
- Fix build path (#82) (Rodolfo Olivieri)
- Fix readthedocs yaml config (#81) (Rodolfo Olivieri)
- Add readthedocs build support (#80) (Rodolfo Olivieri)
- Add sphinx docs (#79) (Rodolfo Olivieri)
- Add 100% docstring coverage (#78) (Rodolfo Olivieri)
- Update dependency coverage to v7.6.10 (#77) (renovate[bot])
- Update systemd release units to be d-bus activable (#72) (Rodolfo Olivieri)
- Improve error handling (#76) (Rodolfo Olivieri)
- Query against rlsrag (#75) (Rodolfo Olivieri)
- Add local history management and improve the command (#74) (Rodolfo Olivieri)
- The connect_signals was triggered the API request twice (#73) (Rodolfo Olivieri)
- Add schema for input/output queries and history (#70) (Rodolfo Olivieri)
- Switch to system bus instead of session bus (#69) (Rodolfo Olivieri)
- Split the query and history dbus implementations (#66) (Rodolfo Olivieri)
- Update specfile to include config from release dir (#68) (Rodolfo Olivieri)
- Enable copr builds in develop (#67) (Rodolfo Olivieri)
- [RSPEED-279] Add Command Line Assistant Daemon (#58) (Rodolfo Olivieri)
- Update dependency coverage to v7.6.9 (#60) (renovate[bot])
- Add an experimental rendering module for client (#62) (Rodolfo Olivieri)
- Refactor the CLI to be separate commands (#61) (Rodolfo Olivieri)
- Add Pull Request template to keep description orgainzed (#49) (Rodolfo Olivieri)
- Update dependency pytest to v8.3.4 (#57) (renovate[bot])
- Add CODEOWNERS file (#52) (Rodolfo Olivieri)
- Remove container testing from pipeline (#51) (Martin "kokesak" Litwora)
- Add more test cases to cover the recent features (#34) (Rodolfo Olivieri)
- Update dependency coverage to v7.6.8 (#48) (renovate[bot])
